@@ -175,34 +175,34 @@ class RequestHandler(BaseProtocol):
         max_headers: int = 32768,
         max_field_size: int = 8190,
         lingering_time: float = 10.0,
-        read_bufsize: int = 2 ** 16,
+        read_bufsize: int = 2**16,
         auto_decompress: bool = True,
     ):
         super().__init__(loop)
 
         self._request_count = 0
         self._keepalive = False
-        self._current_request = None  # type: Optional[BaseRequest]
-        self._manager = manager  # type: Optional[Server]
+        self._current_request: Optional[BaseRequest] = None
+        self._manager: Optional[Server] = manager
         self._request_handler: Optional[_RequestHandler] = manager.request_handler
         self._request_factory: Optional[_RequestFactory] = manager.request_factory
 
         self._tcp_keepalive = tcp_keepalive
         # placeholder to be replaced on keepalive timeout setup
         self._keepalive_time = 0.0
-        self._keepalive_handle = None  # type: Optional[asyncio.Handle]
+        self._keepalive_handle: Optional[asyncio.Handle] = None
         self._keepalive_timeout = keepalive_timeout
         self._lingering_time = float(lingering_time)
 
         self._messages: Deque[_MsgType] = deque()
         self._message_tail = b""
 
-        self._waiter = None  # type: Optional[asyncio.Future[None]]
-        self._task_handler = None  # type: Optional[asyncio.Task[None]]
+        self._waiter: Optional[asyncio.Future[None]] = None
+        self._task_handler: Optional[asyncio.Task[None]] = None
 
         self._upgrade = False
-        self._payload_parser = None  # type: Any
-        self._request_parser = HttpRequestParser(
+        self._payload_parser: Any = None
+        self._request_parser: Optional[HttpRequestParser] = HttpRequestParser(
             self,
             loop,
             read_bufsize,
@@ -211,15 +211,15 @@ class RequestHandler(BaseProtocol):
             max_headers=max_headers,
             payload_exception=RequestPayloadError,
             auto_decompress=auto_decompress,
-        )  # type: Optional[HttpRequestParser]
+        )
 
         self.logger = logger
         self.debug = debug
         self.access_log = access_log
         if access_log:
-            self.access_logger = access_log_class(
+            self.access_logger: Optional[AbstractAccessLogger] = access_log_class(
                 access_log, access_log_format
-            )  # type: Optional[AbstractAccessLogger]
+            )
         else:
             self.access_logger = None
 
@@ -299,8 +299,6 @@ class RequestHandler(BaseProtocol):
                 exc = ConnectionResetError("Connection lost")
             self._current_request._cancel(exc)
 
-        if self._task_handler is not None:
-            self._task_handler.cancel()
         if self._waiter is not None:
             self._waiter.cancel()
 
