@@ -8,22 +8,26 @@ import aiohttp
 
 async def curl(url):
     async with aiohttp.ClientSession() as session:
-        async with session.request('GET', url) as response:
+        async with session.request("GET", url) as response:
             print(repr(response))
             chunk = await response.content.read()
-            print('Downloaded: %s' % len(chunk))
+            print("Downloaded: %s" % len(chunk))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     ARGS = argparse.ArgumentParser(description="GET url example")
-    ARGS.add_argument('url', nargs=1, metavar='URL',
-                      help="URL to download")
-    ARGS.add_argument('--iocp', default=False, action="store_true",
-                      help="Use ProactorEventLoop on Windows")
+    ARGS.add_argument("url", nargs=1, metavar="URL", help="URL to download")
+    ARGS.add_argument(
+        "--iocp",
+        default=False,
+        action="store_true",
+        help="Use ProactorEventLoop on Windows",
+    )
     options = ARGS.parse_args()
 
     if options.iocp:
         from asyncio import events, windows_events
+
         el = windows_events.ProactorEventLoop()
         events.set_event_loop(el)
 
