@@ -11,7 +11,6 @@ import ssl
 from unittest import mock
 
 import pytest
-from async_generator import async_generator, yield_
 from multidict import MultiDict
 from yarl import URL
 
@@ -236,7 +235,8 @@ async def test_post_data_bytesio(aiohttp_client) -> None:
     app.router.add_route("POST", "/", handler)
     client = await aiohttp_client(app)
 
-    resp = await client.post("/", data=io.BytesIO(data))
+    with io.BytesIO(data) as file_handle:
+        resp = await client.post("/", data=file_handle)
     assert 200 == resp.status
 
 
@@ -247,13 +247,15 @@ async def test_post_data_with_bytesio_file(aiohttp_client) -> None:
         post_data = await request.post()
         assert ["file"] == list(post_data.keys())
         assert data == post_data["file"].file.read()
+        post_data["file"].file.close()  # aiohttp < 4 doesn't autoclose files
         return web.Response()
 
     app = web.Application()
     app.router.add_route("POST", "/", handler)
     client = await aiohttp_client(app)
 
-    resp = await client.post("/", data={"file": io.BytesIO(data)})
+    with io.BytesIO(data) as file_handle:
+        resp = await client.post("/", data={"file": file_handle})
     assert 200 == resp.status
 
 
@@ -1238,6 +1240,8 @@ async def test_POST_FILES(aiohttp_client, fname) -> None:
         content2 = data["some"].file.read()
         assert content1 == content2
         assert data["test"].file.read() == b"data"
+        data["some"].file.close()
+        data["test"].file.close()
         return web.Response()
 
     app = web.Application()
@@ -1257,6 +1261,7 @@ async def test_POST_FILES_DEFLATE(aiohttp_client, fname) -> None:
         with fname.open("rb") as f:
             content1 = f.read()
         content2 = data["some"].file.read()
+        data["some"].file.close()
         assert content1 == content2
         return web.Response()
 
@@ -1290,7 +1295,7 @@ async def test_POST_bytes(aiohttp_client) -> None:
 
 
 async def test_POST_bytes_too_large(aiohttp_client) -> None:
-    body = b"0" * (2 ** 20 + 1)
+    body = b"0" * (2**20 + 1)
 
     async def handler(request):
         data = await request.content.read()
@@ -1352,6 +1357,7 @@ async def test_POST_FILES_LIST(aiohttp_client, fname) -> None:
         with fname.open("rb") as f:
             content = f.read()
         assert content == data["some"].file.read()
+        data["some"].file.close()
         return web.Response()
 
     app = web.Application()
@@ -1372,6 +1378,7 @@ async def test_POST_FILES_CT(aiohttp_client, fname) -> None:
         with fname.open("rb") as f:
             content = f.read()
         assert content == data["some"].file.read()
+        data["some"].file.close()
         return web.Response()
 
     app = web.Application()
@@ -1474,16 +1481,17 @@ async def test_POST_FILES_IO(aiohttp_client) -> None:
         assert b"data" == data["unknown"].file.read()
         assert data["unknown"].content_type == "application/octet-stream"
         assert data["unknown"].filename == "unknown"
+        data["unknown"].file.close()
         return web.Response()
 
     app = web.Application()
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
 
-    data = io.BytesIO(b"data")
-    resp = await client.post("/", data=[data])
-    assert 200 == resp.status
-    resp.close()
+    with io.BytesIO(b"data") as file_handle:
+        resp = await client.post("/", data=[file_handle])
+        assert 200 == resp.status
+        resp.close()
 
 
 async def test_POST_FILES_IO_WITH_PARAMS(aiohttp_client) -> None:
@@ -1493,6 +1501,7 @@ async def test_POST_FILES_IO_WITH_PARAMS(aiohttp_client) -> None:
         assert data["unknown"].content_type == "application/octet-stream"
         assert data["unknown"].filename == "unknown"
         assert data["unknown"].file.read() == b"data"
+        data["unknown"].file.close()
         assert data.getall("q") == ["t1", "t2"]
 
         return web.Response()
@@ -1501,12 +1510,13 @@ async def test_POST_FILES_IO_WITH_PARAMS(aiohttp_client) -> None:
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
 
-    data = io.BytesIO(b"data")
-    resp = await client.post(
-        "/", data=(("test", "true"), MultiDict([("q", "t1"), ("q", "t2")]), data)
-    )
-    assert 200 == resp.status
-    resp.close()
+    with io.BytesIO(b"data") as file_handle:
+        resp = await client.post(
+            "/",
+            data=(("test", "true"), MultiDict([("q", "t1"), ("q", "t2")]), file_handle),
+        )
+        assert 200 == resp.status
+        resp.close()
 
 
 async def test_POST_FILES_WITH_DATA(aiohttp_client, fname) -> None:
@@ -1521,6 +1531,7 @@ async def test_POST_FILES_WITH_DATA(aiohttp_client, fname) -> None:
         assert data["some"].filename == fname.name
         with fname.open("rb") as f:
             assert data["some"].file.read() == f.read()
+            data["some"].file.close()
 
         return web.Response()
 
@@ -2428,32 +2439,19 @@ async def test_drop_auth_on_redirect_to_other_host(
 
 
 async def test_async_with_session() -> None:
-    with pytest.warns(None) as cm:
-        async with aiohttp.ClientSession() as session:
-            pass
-    assert len(cm.list) == 0
+    async with aiohttp.ClientSession() as session:
+        pass
 
     assert session.closed
 
 
 async def test_session_close_awaitable() -> None:
     session = aiohttp.ClientSession()
-    with pytest.warns(None) as cm:
-        await session.close()
-    assert len(cm.list) == 0
+    await session.close()
 
     assert session.closed
 
 
-async def test_close_run_until_complete_not_deprecated() -> None:
-    session = aiohttp.ClientSession()
-
-    with pytest.warns(None) as cm:
-        await session.close()
-
-    assert len(cm.list) == 0
-
-
 async def test_close_resp_on_error_async_with_session(aiohttp_server) -> None:
     async def handler(request):
         resp = web.StreamResponse(headers={"content-length": "100"})
@@ -2570,20 +2568,6 @@ async def test_aiohttp_request_ctx_manager_not_found() -> None:
             assert False, "never executed"  # pragma: no cover
 
 
-async def test_aiohttp_request_coroutine(aiohttp_server) -> None:
-    async def handler(request):
-        return web.Response()
-
-    app = web.Application()
-    app.router.add_get("/", handler)
-    server = await aiohttp_server(app)
-
-    with pytest.raises(TypeError):
-        await aiohttp.request("GET", server.make_url("/"))
-
-    server.close()
-
-
 async def test_yield_from_in_session_request(aiohttp_client) -> None:
     # a test for backward compatibility with yield from syntax
     async def handler(request):
@@ -2891,10 +2875,9 @@ async def test_async_payload_generator(aiohttp_client) -> None:
 
     client = await aiohttp_client(app)
 
-    @async_generator
     async def gen():
         for i in range(100):
-            await yield_(b"1234567890")
+            yield b"1234567890"
 
     resp = await client.post("/", data=gen())
     assert resp.status == 200
