@@ -8,7 +8,6 @@ from http.cookies import BaseCookie, Morsel, SimpleCookie
 from unittest import mock
 
 import pytest
-from async_generator import async_generator, yield_
 from multidict import CIMultiDict, CIMultiDictProxy, istr
 from yarl import URL
 
@@ -20,7 +19,7 @@ from aiohttp.client_reqrep import (
     Fingerprint,
     _merge_ssl_params,
 )
-from aiohttp.helpers import PY_310
+from aiohttp.helpers import PY_311
 from aiohttp.test_utils import make_mocked_coro
 
 
@@ -277,7 +276,7 @@ def test_host_header_ipv6_with_port(make_request) -> None:
 
 
 @pytest.mark.xfail(
-    PY_310,
+    PY_311,
     reason="No idea why ClientRequest() is constructed out of loop but "
     "it calls `asyncio.get_event_loop()`",
     raises=DeprecationWarning,
@@ -666,17 +665,18 @@ async def test_content_type_skip_auto_header_form(loop, conn) -> None:
 
 
 async def test_content_type_auto_header_content_length_no_skip(loop, conn) -> None:
-    req = ClientRequest(
-        "post",
-        URL("http://python.org"),
-        data=io.BytesIO(b"hey"),
-        skip_auto_headers={"Content-Length"},
-        loop=loop,
-    )
-    resp = await req.send(conn)
-    assert req.headers.get("CONTENT-LENGTH") == "3"
-    resp.close()
-    await req.close()
+    with io.BytesIO(b"hey") as file_handle:
+        req = ClientRequest(
+            "post",
+            URL("http://python.org"),
+            data=file_handle,
+            skip_auto_headers={"Content-Length"},
+            loop=loop,
+        )
+        resp = await req.send(conn)
+        assert req.headers.get("CONTENT-LENGTH") == "3"
+        resp.close()
+        await req.close()
 
 
 async def test_urlencoded_formdata_charset(loop, conn) -> None:
@@ -942,10 +942,9 @@ async def test_expect_100_continue_header(loop, conn) -> None:
 
 
 async def test_data_stream(loop, buf, conn) -> None:
-    @async_generator
     async def gen():
-        await yield_(b"binary data")
-        await yield_(b" result")
+        yield b"binary data"
+        yield b" result"
 
     req = ClientRequest("POST", URL("http://python.org/"), data=gen(), loop=loop)
     assert req.chunked
@@ -984,30 +983,31 @@ async def test_data_stream_deprecated(loop, buf, conn) -> None:
 
 
 async def test_data_file(loop, buf, conn) -> None:
-    req = ClientRequest(
-        "POST",
-        URL("http://python.org/"),
-        data=io.BufferedReader(io.BytesIO(b"*" * 2)),
-        loop=loop,
-    )
-    assert req.chunked
-    assert isinstance(req.body, payload.BufferedReaderPayload)
-    assert req.headers["TRANSFER-ENCODING"] == "chunked"
+    with io.BufferedReader(io.BytesIO(b"*" * 2)) as file_handle:
+        req = ClientRequest(
+            "POST",
+            URL("http://python.org/"),
+            data=file_handle,
+            loop=loop,
+        )
+        assert req.chunked
+        assert isinstance(req.body, payload.BufferedReaderPayload)
+        assert req.headers["TRANSFER-ENCODING"] == "chunked"
 
-    resp = await req.send(conn)
-    assert asyncio.isfuture(req._writer)
-    await resp.wait_for_close()
-    assert req._writer is None
-    assert buf.split(b"\r\n\r\n", 1)[1] == b"2\r\n" + b"*" * 2 + b"\r\n0\r\n\r\n"
-    await req.close()
+        resp = await req.send(conn)
+        assert asyncio.isfuture(req._writer)
+        await resp.wait_for_close()
+
+        assert req._writer is None
+        assert buf.split(b"\r\n\r\n", 1)[1] == b"2\r\n" + b"*" * 2 + b"\r\n0\r\n\r\n"
+        await req.close()
 
 
 async def test_data_stream_exc(loop, conn) -> None:
     fut = loop.create_future()
 
-    @async_generator
     async def gen():
-        await yield_(b"binary data")
+        yield b"binary data"
         await fut
 
     req = ClientRequest("POST", URL("http://python.org/"), data=gen(), loop=loop)
@@ -1030,9 +1030,10 @@ async def test_data_stream_exc(loop, conn) -> None:
 async def test_data_stream_exc_chain(loop, conn) -> None:
     fut = loop.create_future()
 
-    @async_generator
     async def gen():
         await fut
+        return
+        yield
 
     req = ClientRequest("POST", URL("http://python.org/"), data=gen(), loop=loop)
 
@@ -1056,10 +1057,9 @@ async def test_data_stream_exc_chain(loop, conn) -> None:
 
 
 async def test_data_stream_continue(loop, buf, conn) -> None:
-    @async_generator
     async def gen():
-        await yield_(b"binary data")
-        await yield_(b" result")
+        yield b"binary data"
+        yield b" result"
 
     req = ClientRequest(
         "POST", URL("http://python.org/"), data=gen(), expect100=True, loop=loop
@@ -1101,10 +1101,9 @@ async def test_data_continue(loop, buf, conn) -> None:
 
 
 async def test_close(loop, buf, conn) -> None:
-    @async_generator
     async def gen():
         await asyncio.sleep(0.00001)
-        await yield_(b"result")
+        yield b"result"
 
     req = ClientRequest("POST", URL("http://python.org/"), data=gen(), loop=loop)
     resp = await req.send(conn)
