@@ -1,10 +1,10 @@
 import asyncio
 import contextlib
 import gc
+import io
 import json
 import sys
 from http.cookies import SimpleCookie
-from io import BytesIO
 from typing import Any, List
 from unittest import mock
 
@@ -325,6 +325,7 @@ def test_connector_loop(loop) -> None:
             Matches("Session and connector has to use same event loop")
             == str(ctx.value).strip()
         )
+        another_loop.run_until_complete(connector.close())
 
         # Cannot use `AsyncExitStack` as it's Python 3.7+:
         another_loop.run_until_complete(connector.close())
@@ -401,7 +402,7 @@ async def test_del_debug(connector, loop) -> None:
     assert logs[0] == expected
 
 
-async def test_context_manager(connector, loop) -> None:
+async def test_session_context_manager(connector, loop) -> None:
     with pytest.raises(TypeError):
         with ClientSession(loop=loop, connector=connector) as session:
             pass
@@ -552,60 +553,64 @@ async def test_request_tracing(loop, aiohttp_client) -> None:
     trace_config_ctx = mock.Mock()
     trace_request_ctx = {}
     body = "This is request body"
-    gathered_req_body = BytesIO()
-    gathered_res_body = BytesIO()
     gathered_req_headers = CIMultiDict()
     on_request_start = mock.Mock(side_effect=make_mocked_coro(mock.Mock()))
     on_request_redirect = mock.Mock(side_effect=make_mocked_coro(mock.Mock()))
     on_request_end = mock.Mock(side_effect=make_mocked_coro(mock.Mock()))
 
-    async def on_request_chunk_sent(session, context, params):
-        gathered_req_body.write(params.chunk)
+    with io.BytesIO() as gathered_req_body, io.BytesIO() as gathered_res_body:
 
-    async def on_response_chunk_received(session, context, params):
-        gathered_res_body.write(params.chunk)
+        async def on_request_chunk_sent(session, context, params):
+            gathered_req_body.write(params.chunk)
 
-    async def on_request_headers_sent(session, context, params):
-        gathered_req_headers.extend(**params.headers)
+        async def on_response_chunk_received(session, context, params):
+            gathered_res_body.write(params.chunk)
 
-    trace_config = aiohttp.TraceConfig(
-        trace_config_ctx_factory=mock.Mock(return_value=trace_config_ctx)
-    )
-    trace_config.on_request_start.append(on_request_start)
-    trace_config.on_request_end.append(on_request_end)
-    trace_config.on_request_chunk_sent.append(on_request_chunk_sent)
-    trace_config.on_response_chunk_received.append(on_response_chunk_received)
-    trace_config.on_request_redirect.append(on_request_redirect)
-    trace_config.on_request_headers_sent.append(on_request_headers_sent)
+        async def on_request_headers_sent(session, context, params):
+            gathered_req_headers.extend(**params.headers)
 
-    headers = CIMultiDict({"Custom-Header": "Custom value"})
-    session = await aiohttp_client(app, trace_configs=[trace_config], headers=headers)
+        trace_config = aiohttp.TraceConfig(
+            trace_config_ctx_factory=mock.Mock(return_value=trace_config_ctx)
+        )
+        trace_config.on_request_start.append(on_request_start)
+        trace_config.on_request_end.append(on_request_end)
+        trace_config.on_request_chunk_sent.append(on_request_chunk_sent)
+        trace_config.on_response_chunk_received.append(on_response_chunk_received)
+        trace_config.on_request_redirect.append(on_request_redirect)
+        trace_config.on_request_headers_sent.append(on_request_headers_sent)
 
-    async with session.post(
-        "/", data=body, trace_request_ctx=trace_request_ctx
-    ) as resp:
-
-        await resp.json()
-
-        on_request_start.assert_called_once_with(
-            session.session,
-            trace_config_ctx,
-            aiohttp.TraceRequestStartParams(
-                hdrs.METH_POST, session.make_url("/"), headers
-            ),
+        headers = CIMultiDict({"Custom-Header": "Custom value"})
+        session = await aiohttp_client(
+            app, trace_configs=[trace_config], headers=headers
         )
 
-        on_request_end.assert_called_once_with(
-            session.session,
-            trace_config_ctx,
-            aiohttp.TraceRequestEndParams(
-                hdrs.METH_POST, session.make_url("/"), headers, resp
-            ),
-        )
-        assert not on_request_redirect.called
-        assert gathered_req_body.getvalue() == body.encode("utf8")
-        assert gathered_res_body.getvalue() == json.dumps({"ok": True}).encode("utf8")
-        assert gathered_req_headers["Custom-Header"] == "Custom value"
+        async with session.post(
+            "/", data=body, trace_request_ctx=trace_request_ctx
+        ) as resp:
+
+            await resp.json()
+
+            on_request_start.assert_called_once_with(
+                session.session,
+                trace_config_ctx,
+                aiohttp.TraceRequestStartParams(
+                    hdrs.METH_POST, session.make_url("/"), headers
+                ),
+            )
+
+            on_request_end.assert_called_once_with(
+                session.session,
+                trace_config_ctx,
+                aiohttp.TraceRequestEndParams(
+                    hdrs.METH_POST, session.make_url("/"), headers, resp
+                ),
+            )
+            assert not on_request_redirect.called
+            assert gathered_req_body.getvalue() == body.encode("utf8")
+            assert gathered_res_body.getvalue() == json.dumps({"ok": True}).encode(
+                "utf8"
+            )
+            assert gathered_req_headers["Custom-Header"] == "Custom value"
 
 
 async def test_request_tracing_url_params(loop: Any, aiohttp_client: Any) -> None:
