@@ -2,7 +2,7 @@ from unittest import mock
 
 import pytest
 
-from aiohttp import ClientSession, FormData
+from aiohttp import FormData, web
 
 
 @pytest.fixture
@@ -72,28 +72,36 @@ def test_invalid_formdata_content_transfer_encoding() -> None:
 
 async def test_formdata_field_name_is_quoted(buf, writer) -> None:
     form = FormData(charset="ascii")
-    form.add_field("emails[]", "xxx@x.co", content_type="multipart/form-data")
+    form.add_field("email 1", "xxx@x.co", content_type="multipart/form-data")
     payload = form()
     await payload.write(writer)
-    assert b'name="emails%5B%5D"' in buf
+    assert b'name="email\\ 1"' in buf
 
 
 async def test_formdata_field_name_is_not_quoted(buf, writer) -> None:
     form = FormData(quote_fields=False, charset="ascii")
-    form.add_field("emails[]", "xxx@x.co", content_type="multipart/form-data")
+    form.add_field("email 1", "xxx@x.co", content_type="multipart/form-data")
     payload = form()
     await payload.write(writer)
-    assert b'name="emails[]"' in buf
+    assert b'name="email 1"' in buf
 
 
-async def test_mark_formdata_as_processed() -> None:
-    async with ClientSession() as session:
-        url = "http://httpbin.org/anything"
-        data = FormData()
-        data.add_field("test", "test_value", content_type="application/json")
+async def test_mark_formdata_as_processed(aiohttp_client) -> None:
+    async def handler(request):
+        return web.Response()
 
-        await session.post(url, data=data)
-        assert len(data._writer._parts) == 1
+    app = web.Application()
+    app.add_routes([web.post("/", handler)])
 
-        with pytest.raises(RuntimeError):
-            await session.post(url, data=data)
+    client = await aiohttp_client(app)
+
+    data = FormData()
+    data.add_field("test", "test_value", content_type="application/json")
+
+    resp = await client.post("/", data=data)
+    assert len(data._writer._parts) == 1
+
+    with pytest.raises(RuntimeError):
+        await client.post("/", data=data)
+
+    resp.release()
