@@ -55,7 +55,7 @@ def parser(loop: Any, protocol: Any, request: Any):
     return request.param(
         protocol,
         loop,
-        2 ** 16,
+        2**16,
         max_line_size=8190,
         max_headers=32768,
         max_field_size=8190,
@@ -74,7 +74,7 @@ def response(loop: Any, protocol: Any, request: Any):
     return request.param(
         protocol,
         loop,
-        2 ** 16,
+        2**16,
         max_line_size=8190,
         max_headers=32768,
         max_field_size=8190,
@@ -362,7 +362,15 @@ def test_compression_unknown(parser) -> None:
     assert msg.compression is None
 
 
-def test_headers_connect(parser) -> None:
+def test_url_connect(parser: Any) -> None:
+    text = b"CONNECT www.google.com HTTP/1.1\r\n" b"content-length: 0\r\n\r\n"
+    messages, upgrade, tail = parser.feed_data(text)
+    msg, payload = messages[0]
+    assert upgrade
+    assert msg.url == URL.build(authority="www.google.com")
+
+
+def test_headers_connect(parser: Any) -> None:
     text = b"CONNECT www.google.com HTTP/1.1\r\n" b"content-length: 0\r\n\r\n"
     messages, upgrade, tail = parser.feed_data(text)
     msg, payload = messages[0]
@@ -370,7 +378,19 @@ def test_headers_connect(parser) -> None:
     assert isinstance(payload, streams.StreamReader)
 
 
-def test_headers_old_websocket_key1(parser) -> None:
+def test_url_absolute(parser: Any) -> None:
+    text = (
+        b"GET https://www.google.com/path/to.html HTTP/1.1\r\n"
+        b"content-length: 0\r\n\r\n"
+    )
+    messages, upgrade, tail = parser.feed_data(text)
+    msg, payload = messages[0]
+    assert not upgrade
+    assert msg.method == "GET"
+    assert msg.url == URL("https://www.google.com/path/to.html")
+
+
+def test_headers_old_websocket_key1(parser: Any) -> None:
     text = b"GET /test HTTP/1.1\r\n" b"SEC-WEBSOCKET-KEY1: line\r\n\r\n"
 
     with pytest.raises(http_exceptions.BadHttpMessage):
@@ -759,7 +779,7 @@ def _test_parse_no_length_or_te_on_post(loop, protocol, request_cls):
 
 
 def test_parse_payload_response_without_body(loop, protocol, response_cls) -> None:
-    parser = response_cls(protocol, loop, 2 ** 16, response_with_body=False)
+    parser = response_cls(protocol, loop, 2**16, response_with_body=False)
     text = b"HTTP/1.1 200 Ok\r\n" b"content-length: 10\r\n\r\n"
     msg, payload = parser.feed_data(text)[0][0]
 
@@ -869,7 +889,7 @@ def test_parse_bad_method_for_c_parser_raises(loop, protocol):
     parser = HttpRequestParserC(
         protocol,
         loop,
-        2 ** 16,
+        2**16,
         max_line_size=8190,
         max_headers=32768,
         max_field_size=8190,
@@ -882,7 +902,7 @@ def test_parse_bad_method_for_c_parser_raises(loop, protocol):
 class TestParsePayload:
     async def test_parse_eof_payload(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, readall=True)
         p.feed_data(b"data")
@@ -893,7 +913,7 @@ class TestParsePayload:
 
     async def test_parse_no_body(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, method="PUT")
 
@@ -902,7 +922,7 @@ class TestParsePayload:
 
     async def test_parse_length_payload_eof(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
 
         p = HttpPayloadParser(out, length=4)
@@ -913,7 +933,7 @@ class TestParsePayload:
 
     async def test_parse_chunked_payload_size_error(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, chunked=True)
         with pytest.raises(http_exceptions.TransferEncodingError):
@@ -921,7 +941,7 @@ class TestParsePayload:
         assert isinstance(out.exception(), http_exceptions.TransferEncodingError)
 
     async def test_parse_chunked_payload_split_end(self, protocol) -> None:
-        out = aiohttp.StreamReader(protocol, 2 ** 16, loop=None)
+        out = aiohttp.StreamReader(protocol, 2**16, loop=None)
         p = HttpPayloadParser(out, chunked=True)
         p.feed_data(b"4\r\nasdf\r\n0\r\n")
         p.feed_data(b"\r\n")
@@ -930,7 +950,7 @@ class TestParsePayload:
         assert b"asdf" == b"".join(out._buffer)
 
     async def test_parse_chunked_payload_split_end2(self, protocol) -> None:
-        out = aiohttp.StreamReader(protocol, 2 ** 16, loop=None)
+        out = aiohttp.StreamReader(protocol, 2**16, loop=None)
         p = HttpPayloadParser(out, chunked=True)
         p.feed_data(b"4\r\nasdf\r\n0\r\n\r")
         p.feed_data(b"\n")
@@ -939,7 +959,7 @@ class TestParsePayload:
         assert b"asdf" == b"".join(out._buffer)
 
     async def test_parse_chunked_payload_split_end_trailers(self, protocol) -> None:
-        out = aiohttp.StreamReader(protocol, 2 ** 16, loop=None)
+        out = aiohttp.StreamReader(protocol, 2**16, loop=None)
         p = HttpPayloadParser(out, chunked=True)
         p.feed_data(b"4\r\nasdf\r\n0\r\n")
         p.feed_data(b"Content-MD5: 912ec803b2ce49e4a541068d495ab570\r\n")
@@ -949,7 +969,7 @@ class TestParsePayload:
         assert b"asdf" == b"".join(out._buffer)
 
     async def test_parse_chunked_payload_split_end_trailers2(self, protocol) -> None:
-        out = aiohttp.StreamReader(protocol, 2 ** 16, loop=None)
+        out = aiohttp.StreamReader(protocol, 2**16, loop=None)
         p = HttpPayloadParser(out, chunked=True)
         p.feed_data(b"4\r\nasdf\r\n0\r\n")
         p.feed_data(b"Content-MD5: 912ec803b2ce49e4a541068d495ab570\r\n\r")
@@ -959,7 +979,7 @@ class TestParsePayload:
         assert b"asdf" == b"".join(out._buffer)
 
     async def test_parse_chunked_payload_split_end_trailers3(self, protocol) -> None:
-        out = aiohttp.StreamReader(protocol, 2 ** 16, loop=None)
+        out = aiohttp.StreamReader(protocol, 2**16, loop=None)
         p = HttpPayloadParser(out, chunked=True)
         p.feed_data(b"4\r\nasdf\r\n0\r\nContent-MD5: ")
         p.feed_data(b"912ec803b2ce49e4a541068d495ab570\r\n\r\n")
@@ -968,7 +988,7 @@ class TestParsePayload:
         assert b"asdf" == b"".join(out._buffer)
 
     async def test_parse_chunked_payload_split_end_trailers4(self, protocol) -> None:
-        out = aiohttp.StreamReader(protocol, 2 ** 16, loop=None)
+        out = aiohttp.StreamReader(protocol, 2**16, loop=None)
         p = HttpPayloadParser(out, chunked=True)
         p.feed_data(b"4\r\nasdf\r\n0\r\n" b"C")
         p.feed_data(b"ontent-MD5: 912ec803b2ce49e4a541068d495ab570\r\n\r\n")
@@ -978,7 +998,7 @@ class TestParsePayload:
 
     async def test_http_payload_parser_length(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, length=2)
         eof, tail = p.feed_data(b"1245")
@@ -993,7 +1013,7 @@ class TestParsePayload:
 
         length = len(COMPRESSED)
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, length=length, compression="deflate")
         p.feed_data(COMPRESSED)
@@ -1007,7 +1027,7 @@ class TestParsePayload:
 
         length = len(COMPRESSED)
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, length=length, compression="deflate")
         p.feed_data(COMPRESSED)
@@ -1020,7 +1040,7 @@ class TestParsePayload:
 
         length = len(COMPRESSED)
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, length=length, compression="deflate")
         p.feed_data(COMPRESSED)
@@ -1029,7 +1049,7 @@ class TestParsePayload:
 
     async def test_http_payload_parser_deflate_split(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, compression="deflate", readall=True)
         # Feeding one correct byte should be enough to choose exact
@@ -1041,7 +1061,7 @@ class TestParsePayload:
 
     async def test_http_payload_parser_deflate_split_err(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, compression="deflate", readall=True)
         # Feeding one wrong byte should be enough to choose exact
@@ -1053,7 +1073,7 @@ class TestParsePayload:
 
     async def test_http_payload_parser_length_zero(self, stream) -> None:
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, length=0)
         assert p.done
@@ -1063,7 +1083,7 @@ class TestParsePayload:
     async def test_http_payload_brotli(self, stream) -> None:
         compressed = brotli.compress(b"brotli data")
         out = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         p = HttpPayloadParser(out, length=len(compressed), compression="br")
         p.feed_data(compressed)
@@ -1074,7 +1094,7 @@ class TestParsePayload:
 class TestDeflateBuffer:
     async def test_feed_data(self, stream) -> None:
         buf = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         dbuf = DeflateBuffer(buf, "deflate")
 
@@ -1087,7 +1107,7 @@ class TestDeflateBuffer:
 
     async def test_feed_data_err(self, stream) -> None:
         buf = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         dbuf = DeflateBuffer(buf, "deflate")
 
@@ -1102,7 +1122,7 @@ class TestDeflateBuffer:
 
     async def test_feed_eof(self, stream) -> None:
         buf = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         dbuf = DeflateBuffer(buf, "deflate")
 
@@ -1115,7 +1135,7 @@ class TestDeflateBuffer:
 
     async def test_feed_eof_err_deflate(self, stream) -> None:
         buf = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         dbuf = DeflateBuffer(buf, "deflate")
 
@@ -1128,7 +1148,7 @@ class TestDeflateBuffer:
 
     async def test_feed_eof_no_err_gzip(self, stream) -> None:
         buf = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         dbuf = DeflateBuffer(buf, "gzip")
 
@@ -1141,7 +1161,7 @@ class TestDeflateBuffer:
 
     async def test_feed_eof_no_err_brotli(self, stream) -> None:
         buf = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         dbuf = DeflateBuffer(buf, "br")
 
@@ -1154,7 +1174,7 @@ class TestDeflateBuffer:
 
     async def test_empty_body(self, stream) -> None:
         buf = aiohttp.FlowControlDataQueue(
-            stream, 2 ** 16, loop=asyncio.get_event_loop()
+            stream, 2**16, loop=asyncio.get_event_loop()
         )
         dbuf = DeflateBuffer(buf, "deflate")
         dbuf.feed_eof()
