@@ -16,6 +16,18 @@ from aiohttp import web
 from aiohttp.client_exceptions import ClientConnectionError, ClientProxyConnectionError
 from aiohttp.helpers import IS_MACOS, IS_WINDOWS, PY_37, PY_310
 
+pytestmark = [
+    pytest.mark.filterwarnings(
+        "ignore:unclosed <socket.socket fd=.*:ResourceWarning",
+    ),
+    pytest.mark.filterwarnings(
+        "ignore:"
+        "unclosed transport <_SelectorSocketTransport closing fd=.*"
+        ":ResourceWarning",
+    ),
+]
+
+
 secure_proxy_xfail_under_py310_linux = functools.partial(
     pytest.mark.xfail,
     PY_310 and platform.system() == "Linux",
@@ -33,7 +45,7 @@ ASYNCIO_SUPPORTS_TLS_IN_TLS = hasattr(
 
 
 @pytest.fixture
-def secure_proxy_url(monkeypatch, tls_certificate_pem_path):
+def secure_proxy_url(tls_certificate_pem_path):
     """Return the URL of an instance of a running secure proxy.
 
     This fixture also spawns that instance and tears it down after the test.
@@ -53,18 +65,11 @@ def secure_proxy_url(monkeypatch, tls_certificate_pem_path):
     if not IS_MACOS and not IS_WINDOWS:
         proxypy_args.append("--threadless")  # use asyncio
 
-    class PatchedAccetorPool(proxy.core.acceptor.AcceptorPool):
-        def listen(self):
-            super().listen()
-            self.socket_host, self.socket_port = self.socket.getsockname()[:2]
-
-    monkeypatch.setattr(proxy.proxy, "AcceptorPool", PatchedAccetorPool)
-
     with proxy.Proxy(input_args=proxypy_args) as proxy_instance:
         yield URL.build(
             scheme="https",
-            host=proxy_instance.acceptors.socket_host,
-            port=proxy_instance.acceptors.socket_port,
+            host=str(proxy_instance.flags.hostname),
+            port=proxy_instance.flags.port,
         )
 
 
@@ -348,29 +353,28 @@ async def test_proxy_http_absolute_path(proxy_test_server, get_request) -> None:
     assert len(proxy.requests_list) == 1
     assert proxy.request.method == "GET"
     assert proxy.request.host == "aiohttp.io"
-    assert proxy.request.path_qs == "http://aiohttp.io/path?query=yes"
+    assert proxy.request.path_qs == "/path?query=yes"
 
 
 async def test_proxy_http_raw_path(proxy_test_server, get_request) -> None:
     url = "http://aiohttp.io:2561/space sheep?q=can:fly"
-    raw_url = "http://aiohttp.io:2561/space%20sheep?q=can:fly"
+    raw_url = "/space%20sheep?q=can:fly"
     proxy = await proxy_test_server()
 
     await get_request(url=url, proxy=proxy.url)
 
-    assert proxy.request.host == "aiohttp.io:2561"
+    assert proxy.request.host == "aiohttp.io"
     assert proxy.request.path_qs == raw_url
 
 
 async def test_proxy_http_idna_support(proxy_test_server, get_request) -> None:
     url = "http://éé.com/"
-    raw_url = "http://xn--9caa.com/"
     proxy = await proxy_test_server()
 
     await get_request(url=url, proxy=proxy.url)
 
-    assert proxy.request.host == "xn--9caa.com"
-    assert proxy.request.path_qs == raw_url
+    assert proxy.request.host == "éé.com"
+    assert proxy.request.path_qs == "/"
 
 
 async def test_proxy_http_connection_error(get_request) -> None:
@@ -556,7 +560,7 @@ async def xtest_proxy_https_connect_with_port(proxy_test_server, get_request):
 async def xtest_proxy_https_send_body(proxy_test_server, loop):
     sess = aiohttp.ClientSession(loop=loop)
     proxy = await proxy_test_server()
-    proxy.return_value = {"status": 200, "body": b"1" * (2 ** 20)}
+    proxy.return_value = {"status": 200, "body": b"1" * (2**20)}
     url = "https://www.google.com.ua/search?q=aiohttp proxy"
 
     resp = await sess.get(url, proxy=proxy.url)
@@ -564,7 +568,7 @@ async def xtest_proxy_https_send_body(proxy_test_server, loop):
     await resp.release()
     await sess.close()
 
-    assert body == b"1" * (2 ** 20)
+    assert body == b"1" * (2**20)
 
 
 @pytest.mark.xfail
@@ -766,7 +770,7 @@ async def test_proxy_from_env_http(proxy_test_server, get_request, mocker) -> No
     assert len(proxy.requests_list) == 1
     assert proxy.request.method == "GET"
     assert proxy.request.host == "aiohttp.io"
-    assert proxy.request.path_qs == "http://aiohttp.io/path"
+    assert proxy.request.path_qs == "/path"
     assert "Proxy-Authorization" not in proxy.request.headers
 
 
@@ -788,7 +792,7 @@ async def test_proxy_from_env_http_with_auth(proxy_test_server, get_request, moc
     assert len(proxy.requests_list) == 1
     assert proxy.request.method == "GET"
     assert proxy.request.host == "aiohttp.io"
-    assert proxy.request.path_qs == "http://aiohttp.io/path"
+    assert proxy.request.path_qs == "/path"
     assert proxy.request.headers["Proxy-Authorization"] == auth.encode()
 
 
@@ -814,7 +818,7 @@ async def test_proxy_from_env_http_with_auth_from_netrc(
     assert len(proxy.requests_list) == 1
     assert proxy.request.method == "GET"
     assert proxy.request.host == "aiohttp.io"
-    assert proxy.request.path_qs == "http://aiohttp.io/path"
+    assert proxy.request.path_qs == "/path"
     assert proxy.request.headers["Proxy-Authorization"] == auth.encode()
 
 
@@ -840,7 +844,7 @@ async def test_proxy_from_env_http_without_auth_from_netrc(
     assert len(proxy.requests_list) == 1
     assert proxy.request.method == "GET"
     assert proxy.request.host == "aiohttp.io"
-    assert proxy.request.path_qs == "http://aiohttp.io/path"
+    assert proxy.request.path_qs == "/path"
     assert "Proxy-Authorization" not in proxy.request.headers
 
 
@@ -864,7 +868,7 @@ async def test_proxy_from_env_http_without_auth_from_wrong_netrc(
     assert len(proxy.requests_list) == 1
     assert proxy.request.method == "GET"
     assert proxy.request.host == "aiohttp.io"
-    assert proxy.request.path_qs == "http://aiohttp.io/path"
+    assert proxy.request.path_qs == "/path"
     assert "Proxy-Authorization" not in proxy.request.headers
 
 
@@ -880,7 +884,7 @@ async def xtest_proxy_from_env_https(proxy_test_server, get_request, mocker):
     assert len(proxy.requests_list) == 2
     assert proxy.request.method == "GET"
     assert proxy.request.host == "aiohttp.io"
-    assert proxy.request.path_qs == "https://aiohttp.io/path"
+    assert proxy.request.path_qs == "/path"
     assert "Proxy-Authorization" not in proxy.request.headers
 
 
