@@ -7,7 +7,6 @@ import zlib
 from unittest import mock
 
 import pytest
-from async_generator import async_generator, yield_
 from multidict import CIMultiDictProxy, MultiDict
 from yarl import URL
 
@@ -54,6 +53,8 @@ async def test_simple_get(aiohttp_client) -> None:
     txt = await resp.text()
     assert "OK" == txt
 
+    await resp.release()
+
 
 async def test_simple_get_with_text(aiohttp_client) -> None:
     async def handler(request):
@@ -70,6 +71,8 @@ async def test_simple_get_with_text(aiohttp_client) -> None:
     txt = await resp.text()
     assert "OK" == txt
 
+    await resp.release()
+
 
 async def test_handler_returns_not_response(aiohttp_server, aiohttp_client) -> None:
     asyncio.get_event_loop().set_debug(True)
@@ -141,6 +144,8 @@ async def test_response_before_complete(aiohttp_client) -> None:
     text = await resp.text()
     assert "OK" == text
 
+    await resp.release()
+
 
 async def test_post_form(aiohttp_client) -> None:
     async def handler(request):
@@ -157,6 +162,8 @@ async def test_post_form(aiohttp_client) -> None:
     txt = await resp.text()
     assert "OK" == txt
 
+    await resp.release()
+
 
 async def test_post_text(aiohttp_client) -> None:
     async def handler(request):
@@ -175,6 +182,8 @@ async def test_post_text(aiohttp_client) -> None:
     txt = await resp.text()
     assert "русский" == txt
 
+    await resp.release()
+
 
 async def test_post_json(aiohttp_client) -> None:
 
@@ -200,6 +209,8 @@ async def test_post_json(aiohttp_client) -> None:
     data = await resp.json()
     assert dct == data
 
+    await resp.release()
+
 
 async def test_multipart(aiohttp_client) -> None:
     with multipart.MultipartWriter() as writer:
@@ -298,6 +309,8 @@ async def test_render_redirect(aiohttp_client) -> None:
     assert "301: Moved Permanently" == txt
     assert "/path" == resp.headers["location"]
 
+    await resp.release()
+
 
 async def test_post_single_file(aiohttp_client) -> None:
 
@@ -329,6 +342,8 @@ async def test_post_single_file(aiohttp_client) -> None:
         resp = await client.post("/", data=[fd])
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_files_upload_with_same_key(aiohttp_client) -> None:
     async def handler(request):
@@ -342,6 +357,7 @@ async def test_files_upload_with_same_key(aiohttp_client) -> None:
             if _file.filename == "test2.jpeg":
                 assert _file.file.read() == b"binary data 2"
             file_names.add(_file.filename)
+            _file.file.close()
         assert len(files) == 2
         assert file_names == {"test1.jpeg", "test2.jpeg"}
         resp = web.Response(body=b"OK")
@@ -361,6 +377,8 @@ async def test_files_upload_with_same_key(aiohttp_client) -> None:
     resp = await client.post("/", data=data)
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_post_files(aiohttp_client) -> None:
 
@@ -391,6 +409,8 @@ async def test_post_files(aiohttp_client) -> None:
             resp = await client.post("/", data=[f1, f2])
             assert 200 == resp.status
 
+            await resp.release()
+
 
 async def test_release_post_data(aiohttp_client) -> None:
     async def handler(request):
@@ -406,6 +426,8 @@ async def test_release_post_data(aiohttp_client) -> None:
     resp = await client.post("/", data="post text")
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_POST_DATA_with_content_transfer_encoding(aiohttp_client) -> None:
     async def handler(request):
@@ -423,6 +445,8 @@ async def test_POST_DATA_with_content_transfer_encoding(aiohttp_client) -> None:
     resp = await client.post("/", data=form)
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_post_form_with_duplicate_keys(aiohttp_client) -> None:
     async def handler(request):
@@ -438,6 +462,8 @@ async def test_post_form_with_duplicate_keys(aiohttp_client) -> None:
     resp = await client.post("/", data=MultiDict([("a", 1), ("a", 2)]))
     assert 200 == resp.status
 
+    await resp.release()
+
 
 def test_repr_for_application() -> None:
     app = web.Application()
@@ -469,6 +495,8 @@ async def test_expect_default_handler_unknown(aiohttp_client) -> None:
     resp = await client.post("/", headers={"Expect": "SPAM"})
     assert 417 == resp.status
 
+    await resp.release()
+
 
 async def test_100_continue(aiohttp_client) -> None:
     async def handler(request):
@@ -486,6 +514,8 @@ async def test_100_continue(aiohttp_client) -> None:
     resp = await client.post("/", data=form, expect100=True)
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_100_continue_custom(aiohttp_client) -> None:
 
@@ -510,6 +540,8 @@ async def test_100_continue_custom(aiohttp_client) -> None:
     assert 200 == resp.status
     assert expect_received
 
+    await resp.release()
+
 
 async def test_100_continue_custom_response(aiohttp_client) -> None:
     async def handler(request):
@@ -531,10 +563,12 @@ async def test_100_continue_custom_response(aiohttp_client) -> None:
     auth_err = False
     resp = await client.post("/", data=new_dummy_form(), expect100=True)
     assert 200 == resp.status
+    await resp.release()
 
     auth_err = True
     resp = await client.post("/", data=new_dummy_form(), expect100=True)
     assert 403 == resp.status
+    await resp.release()
 
 
 async def test_100_continue_for_not_found(aiohttp_client) -> None:
@@ -545,6 +579,8 @@ async def test_100_continue_for_not_found(aiohttp_client) -> None:
     resp = await client.post("/not_found", data="data", expect100=True)
     assert 404 == resp.status
 
+    await resp.release()
+
 
 async def test_100_continue_for_not_allowed(aiohttp_client) -> None:
     async def handler(request):
@@ -557,6 +593,8 @@ async def test_100_continue_for_not_allowed(aiohttp_client) -> None:
     resp = await client.get("/", expect100=True)
     assert 405 == resp.status
 
+    await resp.release()
+
 
 async def test_http11_keep_alive_default(aiohttp_client) -> None:
     async def handler(request):
@@ -571,6 +609,8 @@ async def test_http11_keep_alive_default(aiohttp_client) -> None:
     assert resp.version == HttpVersion11
     assert "Connection" not in resp.headers
 
+    await resp.release()
+
 
 @pytest.mark.xfail
 async def test_http10_keep_alive_default(aiohttp_client) -> None:
@@ -586,6 +626,8 @@ async def test_http10_keep_alive_default(aiohttp_client) -> None:
     assert resp.version == HttpVersion10
     assert resp.headers["Connection"] == "keep-alive"
 
+    await resp.release()
+
 
 async def test_http10_keep_alive_with_headers_close(aiohttp_client) -> None:
     async def handler(request):
@@ -602,6 +644,8 @@ async def test_http10_keep_alive_with_headers_close(aiohttp_client) -> None:
     assert resp.version == HttpVersion10
     assert "Connection" not in resp.headers
 
+    await resp.release()
+
 
 async def test_http10_keep_alive_with_headers(aiohttp_client) -> None:
     async def handler(request):
@@ -618,6 +662,8 @@ async def test_http10_keep_alive_with_headers(aiohttp_client) -> None:
     assert resp.version == HttpVersion10
     assert resp.headers["Connection"] == "keep-alive"
 
+    await resp.release()
+
 
 async def test_upload_file(aiohttp_client) -> None:
 
@@ -629,6 +675,7 @@ async def test_upload_file(aiohttp_client) -> None:
     async def handler(request):
         form = await request.post()
         raw_data = form["file"].file.read()
+        form["file"].file.close()
         assert data == raw_data
         return web.Response()
 
@@ -639,6 +686,8 @@ async def test_upload_file(aiohttp_client) -> None:
     resp = await client.post("/", data={"file": data})
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_upload_file_object(aiohttp_client) -> None:
     here = pathlib.Path(__file__).parent
@@ -649,6 +698,7 @@ async def test_upload_file_object(aiohttp_client) -> None:
     async def handler(request):
         form = await request.post()
         raw_data = form["file"].file.read()
+        form["file"].file.close()
         assert data == raw_data
         return web.Response()
 
@@ -660,6 +710,8 @@ async def test_upload_file_object(aiohttp_client) -> None:
         resp = await client.post("/", data={"file": f})
         assert 200 == resp.status
 
+        await resp.release()
+
 
 @pytest.mark.parametrize(
     "method", ["get", "post", "options", "post", "put", "patch", "delete"]
@@ -696,6 +748,8 @@ async def test_empty_content_for_query_with_body(aiohttp_client) -> None:
     resp = await client.post("/", data=b"data")
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_get_with_empty_arg(aiohttp_client) -> None:
     async def handler(request):
@@ -710,6 +764,8 @@ async def test_get_with_empty_arg(aiohttp_client) -> None:
     resp = await client.get("/?arg")
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_large_header(aiohttp_client) -> None:
     async def handler(request):
@@ -723,6 +779,8 @@ async def test_large_header(aiohttp_client) -> None:
     resp = await client.get("/", headers=headers)
     assert 400 == resp.status
 
+    await resp.release()
+
 
 async def test_large_header_allowed(aiohttp_client, aiohttp_server) -> None:
     async def handler(request):
@@ -737,6 +795,8 @@ async def test_large_header_allowed(aiohttp_client, aiohttp_server) -> None:
     resp = await client.post("/", headers=headers)
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_get_with_empty_arg_with_equal(aiohttp_client) -> None:
     async def handler(request):
@@ -751,6 +811,8 @@ async def test_get_with_empty_arg_with_equal(aiohttp_client) -> None:
     resp = await client.get("/?arg=")
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_response_with_async_gen(aiohttp_client, fname) -> None:
 
@@ -759,12 +821,11 @@ async def test_response_with_async_gen(aiohttp_client, fname) -> None:
 
     data_size = len(data)
 
-    @async_generator
     async def stream(f_name):
         with f_name.open("rb") as f:
             data = f.read(100)
             while data:
-                await yield_(data)
+                yield data
                 data = f.read(100)
 
     async def handler(request):
@@ -781,6 +842,8 @@ async def test_response_with_async_gen(aiohttp_client, fname) -> None:
     assert resp_data == data
     assert resp.headers.get("Content-Length") == str(len(resp_data))
 
+    await resp.release()
+
 
 async def test_response_with_streamer(aiohttp_client, fname) -> None:
 
@@ -821,12 +884,11 @@ async def test_response_with_async_gen_no_params(aiohttp_client, fname) -> None:
 
     data_size = len(data)
 
-    @async_generator
     async def stream():
         with fname.open("rb") as f:
             data = f.read(100)
             while data:
-                await yield_(data)
+                yield data
                 data = f.read(100)
 
     async def handler(request):
@@ -843,6 +905,8 @@ async def test_response_with_async_gen_no_params(aiohttp_client, fname) -> None:
     assert resp_data == data
     assert resp.headers.get("Content-Length") == str(len(resp_data))
 
+    await resp.release()
+
 
 async def test_response_with_streamer_no_params(aiohttp_client, fname) -> None:
 
@@ -904,6 +968,8 @@ async def test_response_with_file(aiohttp_client, fname) -> None:
     assert resp.headers.get("Content-Length") == str(len(resp_data))
     assert resp.headers.get("Content-Disposition") == expected_content_disposition
 
+    await resp.release()
+
     outer_file_descriptor.close()
 
 
@@ -934,6 +1000,8 @@ async def test_response_with_file_ctype(aiohttp_client, fname) -> None:
     assert resp.headers.get("Content-Length") == str(len(resp_data))
     assert resp.headers.get("Content-Disposition") == expected_content_disposition
 
+    await resp.release()
+
     outer_file_descriptor.close()
 
 
@@ -962,6 +1030,8 @@ async def test_response_with_payload_disp(aiohttp_client, fname) -> None:
     assert resp.headers.get("Content-Length") == str(len(resp_data))
     assert resp.headers.get("Content-Disposition") == 'inline; filename="test.txt"'
 
+    await resp.release()
+
     outer_file_descriptor.close()
 
 
@@ -978,6 +1048,8 @@ async def test_response_with_payload_stringio(aiohttp_client, fname) -> None:
     resp_data = await resp.read()
     assert resp_data == b"test"
 
+    await resp.release()
+
 
 async def test_response_with_precompressed_body_gzip(aiohttp_client) -> None:
     async def handler(request):
@@ -996,6 +1068,8 @@ async def test_response_with_precompressed_body_gzip(aiohttp_client) -> None:
     assert b"mydata" == data
     assert resp.headers.get("Content-Encoding") == "gzip"
 
+    await resp.release()
+
 
 async def test_response_with_precompressed_body_deflate(aiohttp_client) -> None:
     async def handler(request):
@@ -1014,6 +1088,8 @@ async def test_response_with_precompressed_body_deflate(aiohttp_client) -> None:
     assert b"mydata" == data
     assert resp.headers.get("Content-Encoding") == "deflate"
 
+    await resp.release()
+
 
 async def test_response_with_precompressed_body_deflate_no_hdrs(aiohttp_client) -> None:
     async def handler(request):
@@ -1051,6 +1127,8 @@ async def test_bad_request_payload(aiohttp_client) -> None:
     resp = await client.post("/", data=b"test", headers={"content-encoding": "gzip"})
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_stream_response_multiple_chunks(aiohttp_client) -> None:
     async def handler(request):
@@ -1071,6 +1149,8 @@ async def test_stream_response_multiple_chunks(aiohttp_client) -> None:
     data = await resp.read()
     assert b"xyz" == data
 
+    await resp.release()
+
 
 async def test_start_without_routes(aiohttp_client) -> None:
 
@@ -1080,6 +1160,8 @@ async def test_start_without_routes(aiohttp_client) -> None:
     resp = await client.get("/")
     assert 404 == resp.status
 
+    await resp.release()
+
 
 async def test_requests_count(aiohttp_client) -> None:
     async def handler(request):
@@ -1093,14 +1175,17 @@ async def test_requests_count(aiohttp_client) -> None:
     resp = await client.get("/")
     assert 200 == resp.status
     assert client.server.handler.requests_count == 1
+    await resp.release()
 
     resp = await client.get("/")
     assert 200 == resp.status
     assert client.server.handler.requests_count == 2
+    await resp.release()
 
     resp = await client.get("/")
     assert 200 == resp.status
     assert client.server.handler.requests_count == 3
+    await resp.release()
 
 
 async def test_redirect_url(aiohttp_client) -> None:
@@ -1118,6 +1203,8 @@ async def test_redirect_url(aiohttp_client) -> None:
     resp = await client.get("/redirector")
     assert resp.status == 200
 
+    await resp.release()
+
 
 async def test_simple_subapp(aiohttp_client) -> None:
     async def handler(request):
@@ -1134,6 +1221,8 @@ async def test_simple_subapp(aiohttp_client) -> None:
     txt = await resp.text()
     assert "OK" == txt
 
+    await resp.release()
+
 
 async def test_subapp_reverse_url(aiohttp_client) -> None:
     async def handler(request):
@@ -1155,6 +1244,8 @@ async def test_subapp_reverse_url(aiohttp_client) -> None:
     assert "OK" == txt
     assert resp.url.path == "/path/final"
 
+    await resp.release()
+
 
 async def test_subapp_reverse_variable_url(aiohttp_client) -> None:
     async def handler(request):
@@ -1178,6 +1269,8 @@ async def test_subapp_reverse_variable_url(aiohttp_client) -> None:
     assert "OK" == txt
     assert resp.url.path == "/path/final"
 
+    await resp.release()
+
 
 async def test_subapp_reverse_static_url(aiohttp_client) -> None:
     fname = "aiohttp.png"
@@ -1199,6 +1292,9 @@ async def test_subapp_reverse_static_url(aiohttp_client) -> None:
     assert resp.url.path == "/path/static/" + fname
     assert resp.status == 200
     body = await resp.read()
+
+    await resp.release()
+
     with (here / fname).open("rb") as f:
         assert body == f.read()
 
@@ -1219,6 +1315,8 @@ async def test_subapp_app(aiohttp_client) -> None:
     txt = await resp.text()
     assert "OK" == txt
 
+    await resp.release()
+
 
 async def test_subapp_not_found(aiohttp_client) -> None:
     async def handler(request):
@@ -1233,6 +1331,8 @@ async def test_subapp_not_found(aiohttp_client) -> None:
     resp = await client.get("/path/other")
     assert resp.status == 404
 
+    await resp.release()
+
 
 async def test_subapp_not_found2(aiohttp_client) -> None:
     async def handler(request):
@@ -1247,6 +1347,8 @@ async def test_subapp_not_found2(aiohttp_client) -> None:
     resp = await client.get("/invalid/other")
     assert resp.status == 404
 
+    await resp.release()
+
 
 async def test_subapp_not_allowed(aiohttp_client) -> None:
     async def handler(request):
@@ -1262,6 +1364,8 @@ async def test_subapp_not_allowed(aiohttp_client) -> None:
     assert resp.status == 405
     assert resp.headers["Allow"] == "GET,HEAD"
 
+    await resp.release()
+
 
 async def test_subapp_cannot_add_app_in_handler(aiohttp_client) -> None:
     async def handler(request):
@@ -1277,6 +1381,8 @@ async def test_subapp_cannot_add_app_in_handler(aiohttp_client) -> None:
     resp = await client.get("/path/to")
     assert resp.status == 500
 
+    await resp.release()
+
 
 async def test_subapp_middlewares(aiohttp_client) -> None:
     order = []
@@ -1314,6 +1420,8 @@ async def test_subapp_middlewares(aiohttp_client) -> None:
         (2, app),
     ] == order
 
+    await resp.release()
+
 
 async def test_subapp_on_response_prepare(aiohttp_client) -> None:
     order = []
@@ -1342,6 +1450,8 @@ async def test_subapp_on_response_prepare(aiohttp_client) -> None:
     assert resp.status == 200
     assert [app, subapp1, subapp2] == order
 
+    await resp.release()
+
 
 async def test_subapp_on_startup(aiohttp_server) -> None:
     order = []
@@ -1455,6 +1565,8 @@ async def test_subapp_middleware_context(aiohttp_client, route, expected, middle
     assert "Ok" == await resp.text()
     assert expected == values
 
+    await resp.release()
+
 
 async def test_custom_date_header(aiohttp_client) -> None:
     async def handler(request):
@@ -1468,6 +1580,8 @@ async def test_custom_date_header(aiohttp_client) -> None:
     assert 200 == resp.status
     assert resp.headers["Date"] == "Sun, 30 Oct 2016 03:13:52 GMT"
 
+    await resp.release()
+
 
 async def test_response_prepared_with_clone(aiohttp_client) -> None:
     async def handler(request):
@@ -1483,13 +1597,15 @@ async def test_response_prepared_with_clone(aiohttp_client) -> None:
     resp = await client.get("/")
     assert 200 == resp.status
 
+    await resp.release()
+
 
 async def test_app_max_client_size(aiohttp_client) -> None:
     async def handler(request):
         await request.post()
         return web.Response(body=b"ok")
 
-    max_size = 1024 ** 2
+    max_size = 1024**2
     app = web.Application()
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
@@ -1505,23 +1621,28 @@ async def test_app_max_client_size(aiohttp_client) -> None:
     body_size = int(resp_text.split()[-1])
     assert body_size >= max_size
 
+    await resp.release()
+
 
 async def test_app_max_client_size_adjusted(aiohttp_client) -> None:
     async def handler(request):
         await request.post()
         return web.Response(body=b"ok")
 
-    default_max_size = 1024 ** 2
+    default_max_size = 1024**2
     custom_max_size = default_max_size * 2
     app = web.Application(client_max_size=custom_max_size)
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
     data = {"long_string": default_max_size * "x" + "xxx"}
+
     with pytest.warns(ResourceWarning):
         resp = await client.post("/", data=data)
     assert 200 == resp.status
     resp_text = await resp.text()
     assert "ok" == resp_text
+    await resp.release()
+
     too_large_data = {"log_string": custom_max_size * "x" + "xxx"}
     with pytest.warns(ResourceWarning):
         resp = await client.post("/", data=too_large_data)
@@ -1534,29 +1655,35 @@ async def test_app_max_client_size_adjusted(aiohttp_client) -> None:
     body_size = int(resp_text.split()[-1])
     assert body_size >= custom_max_size
 
+    await resp.release()
+
 
 async def test_app_max_client_size_none(aiohttp_client) -> None:
     async def handler(request):
         await request.post()
         return web.Response(body=b"ok")
 
-    default_max_size = 1024 ** 2
+    default_max_size = 1024**2
     custom_max_size = None
     app = web.Application(client_max_size=custom_max_size)
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
+
     data = {"long_string": default_max_size * "x" + "xxx"}
     with pytest.warns(ResourceWarning):
         resp = await client.post("/", data=data)
     assert 200 == resp.status
     resp_text = await resp.text()
     assert "ok" == resp_text
+    await resp.release()
+
     too_large_data = {"log_string": default_max_size * 2 * "x"}
     with pytest.warns(ResourceWarning):
         resp = await client.post("/", data=too_large_data)
     assert 200 == resp.status
     resp_text = await resp.text()
     assert resp_text == "ok"
+    await resp.release()
 
 
 async def test_post_max_client_size(aiohttp_client) -> None:
@@ -1568,15 +1695,19 @@ async def test_post_max_client_size(aiohttp_client) -> None:
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
 
-    data = {"long_string": 1024 * "x", "file": io.BytesIO(b"test")}
-    resp = await client.post("/", data=data)
+    with io.BytesIO(b"test") as file_handle:
+        data = {"long_string": 1024 * "x", "file": file_handle}
+        resp = await client.post("/", data=data)
 
-    assert 413 == resp.status
-    resp_text = await resp.text()
-    assert (
-        "Maximum request body size 10 exceeded, " "actual body size 1024" in resp_text
-    )
-    data["file"].close()
+        assert 413 == resp.status
+        resp_text = await resp.text()
+        assert (
+            "Maximum request body size 10 exceeded, "
+            "actual body size 1024" in resp_text
+        )
+        data["file"].close()
+
+        await resp.release()
 
 
 async def test_post_max_client_size_for_file(aiohttp_client) -> None:
@@ -1588,11 +1719,14 @@ async def test_post_max_client_size_for_file(aiohttp_client) -> None:
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
 
-    data = {"file": io.BytesIO(b"test")}
-    resp = await client.post("/", data=data)
+    with io.BytesIO(b"test") as file_handle:
+        data = {"file": file_handle}
+        resp = await client.post("/", data=data)
 
     assert 413 == resp.status
 
+    await resp.release()
+
 
 async def test_response_with_bodypart(aiohttp_client) -> None:
     async def handler(request):
@@ -1604,15 +1738,18 @@ async def test_response_with_bodypart(aiohttp_client) -> None:
     app.router.add_post("/", handler)
     client = await aiohttp_client(app)
 
-    data = {"file": io.BytesIO(b"test")}
-    resp = await client.post("/", data=data)
+    with io.BytesIO(b"test") as file_handle:
+        data = {"file": file_handle}
+        resp = await client.post("/", data=data)
 
-    assert 200 == resp.status
-    body = await resp.read()
-    assert body == b"test"
+        assert 200 == resp.status
+        body = await resp.read()
+        assert body == b"test"
 
-    disp = multipart.parse_content_disposition(resp.headers["content-disposition"])
-    assert disp == ("attachment", {"name": "file", "filename": "file"})
+        disp = multipart.parse_content_disposition(resp.headers["content-disposition"])
+        assert disp == ("attachment", {"name": "file", "filename": "file"})
+
+        await resp.release()
 
 
 async def test_response_with_bodypart_named(aiohttp_client, tmpdir) -> None:
@@ -1638,6 +1775,8 @@ async def test_response_with_bodypart_named(aiohttp_client, tmpdir) -> None:
     disp = multipart.parse_content_disposition(resp.headers["content-disposition"])
     assert disp == ("attachment", {"name": "file", "filename": "foobar.txt"})
 
+    await resp.release()
+
 
 async def test_response_with_bodypart_invalid_name(aiohttp_client) -> None:
     async def handler(request):
@@ -1659,6 +1798,8 @@ async def test_response_with_bodypart_invalid_name(aiohttp_client) -> None:
 
     assert "content-disposition" not in resp.headers
 
+    await resp.release()
+
 
 async def test_request_clone(aiohttp_client) -> None:
     async def handler(request):
@@ -1673,6 +1814,7 @@ async def test_request_clone(aiohttp_client) -> None:
 
     resp = await client.get("/")
     assert 200 == resp.status
+    await resp.release()
 
 
 async def test_await(aiohttp_server) -> None:
@@ -1857,7 +1999,7 @@ async def test_request_tracing(aiohttp_server) -> None:
     connector = aiohttp.TCPConnector(resolver=resolver)
     client = aiohttp.ClientSession(connector=connector, trace_configs=[trace_config])
 
-    await client.get("http://example.com/redirector", data="foo")
+    resp = await client.get("http://example.com/redirector", data="foo")
 
     assert on_request_start.called
     assert on_request_end.called
@@ -1866,6 +2008,8 @@ async def test_request_tracing(aiohttp_server) -> None:
     assert on_request_redirect.called
     assert on_connection_create_start.called
     assert on_connection_create_end.called
+
+    await resp.release()
     await client.close()
 
 
@@ -1896,6 +2040,7 @@ async def test_request_path(aiohttp_client) -> None:
     assert 200 == resp.status
     txt = await resp.text()
     assert "OK" == txt
+    await resp.release()
 
 
 async def test_app_add_routes(aiohttp_client) -> None:
@@ -1908,6 +2053,7 @@ async def test_app_add_routes(aiohttp_client) -> None:
     client = await aiohttp_client(app)
     resp = await client.get("/get")
     assert resp.status == 200
+    await resp.release()
 
 
 async def test_request_headers_type(aiohttp_client) -> None:
@@ -1921,6 +2067,7 @@ async def test_request_headers_type(aiohttp_client) -> None:
     client = await aiohttp_client(app)
     resp = await client.get("/get")
     assert resp.status == 200
+    await resp.release()
 
 
 async def test_signal_on_error_handler(aiohttp_client) -> None:
@@ -1934,6 +2081,7 @@ async def test_signal_on_error_handler(aiohttp_client) -> None:
     resp = await client.get("/")
     assert resp.status == 404
     assert resp.headers["X-Custom"] == "val"
+    await resp.release()
 
 
 @pytest.mark.skipif(
@@ -1961,6 +2109,7 @@ async def test_read_bufsize(aiohttp_client) -> None:
     resp = await client.post("/", data=b"data")
     assert resp.status == 200
     assert await resp.text() == "data (2, 4)"
+    await resp.release()
 
 
 @pytest.mark.parametrize(
@@ -1987,6 +2136,7 @@ async def test_auto_decompress(
     resp = await client.post("/", data=compressed, headers=headers)
     assert resp.status == 200
     assert await resp.text() == str(len(locals()[len_of]))
+    await resp.release()
 
 
 @pytest.mark.parametrize(
@@ -2005,6 +2155,7 @@ async def test_response_101_204_no_content_length_http11(
     resp = await client.get("/")
     assert CONTENT_LENGTH not in resp.headers
     assert TRANSFER_ENCODING not in resp.headers
+    await resp.release()
 
 
 async def test_stream_response_headers_204(aiohttp_client):
@@ -2017,3 +2168,4 @@ async def test_stream_response_headers_204(aiohttp_client):
     resp = await client.get("/")
     assert CONTENT_TYPE not in resp.headers
     assert TRANSFER_ENCODING not in resp.headers
+    await resp.release()
