@@ -1,4 +1,4 @@
-"""Tests for aiohttp/worker.py"""
+# Tests for aiohttp/worker.py
 import asyncio
 import os
 import socket
@@ -9,7 +9,7 @@ import pytest
 
 from aiohttp import web
 
-base_worker = pytest.importorskip('aiohttp.worker')
+base_worker = pytest.importorskip("aiohttp.worker")
 
 
 try:
@@ -24,31 +24,31 @@ ACCEPTABLE_LOG_FORMAT = '%a "%{Referrer}i" %s'
 
 # tokio event loop does not allow to override attributes
 def skip_if_no_dict(loop):
-    if not hasattr(loop, '__dict__'):
+    if not hasattr(loop, "__dict__"):
         pytest.skip("can not override loop attributes")
 
 
 class BaseTestWorker:
-
     def __init__(self):
         self.servers = {}
         self.exit_code = 0
         self._notify_waiter = None
         self.cfg = mock.Mock()
         self.cfg.graceful_timeout = 100
-        self.pid = 'pid'
+        self.pid = "pid"
         self.wsgi = web.Application()
 
 
-class AsyncioWorker(BaseTestWorker,  # type: ignore
-                    base_worker.GunicornWebWorker):
+class AsyncioWorker(BaseTestWorker, base_worker.GunicornWebWorker):  # type: ignore
     pass
 
 
 PARAMS = [AsyncioWorker]
 if uvloop is not None:
-    class UvloopWorker(BaseTestWorker,  # type: ignore
-                       base_worker.GunicornUVLoopWebWorker):
+
+    class UvloopWorker(
+        BaseTestWorker, base_worker.GunicornUVLoopWebWorker  # type: ignore
+    ):
         pass
 
     PARAMS.append(UvloopWorker)
@@ -63,7 +63,7 @@ def worker(request, loop):
 
 
 def test_init_process(worker) -> None:
-    with mock.patch('aiohttp.worker.asyncio') as m_asyncio:
+    with mock.patch("aiohttp.worker.asyncio") as m_asyncio:
         try:
             worker.init_process()
         except TypeError:
@@ -98,6 +98,7 @@ def test_run_async_factory(worker, loop) -> None:
 
     async def make_app():
         return app
+
     worker.wsgi = make_app
 
     worker.loop = loop
@@ -118,7 +119,7 @@ def test_run_not_app(worker, loop) -> None:
     worker.alive = False
     with pytest.raises(SystemExit):
         worker.run()
-    worker.log.exception.assert_called_with('Exception in gunicorn worker')
+    worker.log.exception.assert_called_with("Exception in gunicorn worker")
     assert loop.is_closed()
 
 
@@ -127,12 +128,11 @@ def test_handle_quit(worker, loop) -> None:
     worker.handle_quit(object(), object())
     assert not worker.alive
     assert worker.exit_code == 0
-    worker.loop.call_later.asset_called_with(
-        0.1, worker._notify_waiter_done)
+    worker.loop.call_later.asset_called_with(0.1, worker._notify_waiter_done)
 
 
 def test_handle_abort(worker) -> None:
-    with mock.patch('aiohttp.worker.sys') as m_sys:
+    with mock.patch("aiohttp.worker.sys") as m_sys:
         worker.handle_abort(object(), object())
         assert not worker.alive
         assert worker.exit_code == 1
@@ -145,9 +145,7 @@ def test__wait_next_notify(worker) -> None:
     fut = worker._wait_next_notify()
 
     assert worker._notify_waiter == fut
-    worker.loop.call_later.assert_called_with(1.0,
-                                              worker._notify_waiter_done,
-                                              fut)
+    worker.loop.call_later.assert_called_with(1.0, worker._notify_waiter_done, fut)
 
 
 def test__notify_waiter_done(worker) -> None:
@@ -183,11 +181,16 @@ def test_init_signals(worker) -> None:
     assert worker.loop.add_signal_handler.called
 
 
-@pytest.mark.parametrize('source,result', [
-    (ACCEPTABLE_LOG_FORMAT, ACCEPTABLE_LOG_FORMAT),
-    (AsyncioWorker.DEFAULT_GUNICORN_LOG_FORMAT,
-     AsyncioWorker.DEFAULT_AIOHTTP_LOG_FORMAT),
-])
+@pytest.mark.parametrize(
+    "source,result",
+    [
+        (ACCEPTABLE_LOG_FORMAT, ACCEPTABLE_LOG_FORMAT),
+        (
+            AsyncioWorker.DEFAULT_GUNICORN_LOG_FORMAT,
+            AsyncioWorker.DEFAULT_AIOHTTP_LOG_FORMAT,
+        ),
+    ],
+)
 def test__get_valid_log_format_ok(worker, source, result) -> None:
     assert result == worker._get_valid_log_format(source)
 
@@ -195,17 +198,16 @@ def test__get_valid_log_format_ok(worker, source, result) -> None:
 def test__get_valid_log_format_exc(worker) -> None:
     with pytest.raises(ValueError) as exc:
         worker._get_valid_log_format(WRONG_LOG_FORMAT)
-    assert '%(name)s' in str(exc.value)
+    assert "%(name)s" in str(exc.value)
 
 
-async def test__run_ok_parent_changed(worker, loop,
-                                      aiohttp_unused_port) -> None:
+async def test__run_ok_parent_changed(worker, loop, aiohttp_unused_port) -> None:
     skip_if_no_dict(loop)
 
     worker.ppid = 0
     worker.alive = True
     sock = socket.socket()
-    addr = ('localhost', aiohttp_unused_port())
+    addr = ("localhost", aiohttp_unused_port())
     sock.bind(addr)
     worker.sockets = [sock]
     worker.log = mock.Mock()
@@ -217,8 +219,7 @@ async def test__run_ok_parent_changed(worker, loop,
     await worker._run()
 
     worker.notify.assert_called_with()
-    worker.log.info.assert_called_with("Parent changed, shutting down: %s",
-                                       worker)
+    worker.log.info.assert_called_with("Parent changed, shutting down: %s", worker)
 
 
 async def test__run_exc(worker, loop, aiohttp_unused_port) -> None:
@@ -227,7 +228,7 @@ async def test__run_exc(worker, loop, aiohttp_unused_port) -> None:
     worker.ppid = os.getppid()
     worker.alive = True
     sock = socket.socket()
-    addr = ('localhost', aiohttp_unused_port())
+    addr = ("localhost", aiohttp_unused_port())
     sock.bind(addr)
     worker.sockets = [sock]
     worker.log = mock.Mock()
@@ -248,10 +249,10 @@ async def test__run_exc(worker, loop, aiohttp_unused_port) -> None:
 
 
 def test__create_ssl_context_without_certs_and_ciphers(
-        worker,
-        tls_certificate_pem_path,
+    worker,
+    tls_certificate_pem_path,
 ) -> None:
-    worker.cfg.ssl_version = ssl.PROTOCOL_SSLv23
+    worker.cfg.ssl_version = ssl.PROTOCOL_TLS_CLIENT
     worker.cfg.cert_reqs = ssl.CERT_OPTIONAL
     worker.cfg.certfile = tls_certificate_pem_path
     worker.cfg.keyfile = tls_certificate_pem_path
@@ -262,24 +263,25 @@ def test__create_ssl_context_without_certs_and_ciphers(
 
 
 def test__create_ssl_context_with_ciphers(
-        worker,
-        tls_certificate_pem_path,
+    worker,
+    tls_certificate_pem_path,
 ) -> None:
-    worker.cfg.ssl_version = ssl.PROTOCOL_SSLv23
+    worker.cfg.ssl_version = ssl.PROTOCOL_TLS_CLIENT
     worker.cfg.cert_reqs = ssl.CERT_OPTIONAL
     worker.cfg.certfile = tls_certificate_pem_path
     worker.cfg.keyfile = tls_certificate_pem_path
     worker.cfg.ca_certs = None
-    worker.cfg.ciphers = '3DES PSK'
+    worker.cfg.ciphers = "3DES PSK"
     ctx = worker._create_ssl_context(worker.cfg)
     assert isinstance(ctx, ssl.SSLContext)
 
 
 def test__create_ssl_context_with_ca_certs(
-        worker,
-        tls_ca_certificate_pem_path, tls_certificate_pem_path,
+    worker,
+    tls_ca_certificate_pem_path,
+    tls_certificate_pem_path,
 ) -> None:
-    worker.cfg.ssl_version = ssl.PROTOCOL_SSLv23
+    worker.cfg.ssl_version = ssl.PROTOCOL_TLS_CLIENT
     worker.cfg.cert_reqs = ssl.CERT_OPTIONAL
     worker.cfg.certfile = tls_certificate_pem_path
     worker.cfg.keyfile = tls_certificate_pem_path
